# -*- coding: UTF-8 -*-
import requests
from bs4 import BeautifulSoup
from functools import wraps
import urllib.parse

def Deprecated(func):
    @wraps(func)
    def wrapper(*args):
        print('函数已经被弃用:',func.__name__)
        return func(*args)
    return wrapper

def Developing(func):
    @wraps(func)
    def wrapper(*args):
        print('函数还在开发中:',func.__name__)
        return func(*args)
    return wrapper

class LuoguLogin(requests.auth.AuthBase):
    @Developing
    def __init__(self,username,password,captcha):
        self.username = username
        self.password = password
        self.captcha = captcha
    @Developing
    def __call__(self,r):
        # 实现
        return r

class Luogu(object):
    def __init__(self,username,password,ua):
        self.__username = username
        self.__password = password
        self.__syncToken = ''
        self.__uid = 0 # Deprecated
        self.__headers = {
            'User-Agent': ua,
            'referer': 'https://www.luogu.com.cn/',
            'x-luogu-type': 'content-only'
        }
        self.__session = requests.session()

    def getcsrf(self,addr):
        r = self.__session.get(addr,headers=self.__headers)
        if not r.status_code == 200:
            raise AttributeError()
        soup = BeautifulSoup(r.text,features='html.parser')
        self.__headers['x-csrf-token'] = soup.find(attrs={'name': 'csrf-token'})['content']

    def getLoginCaptcha(self):
        return self.__session.get('https://www.luogu.com.cn/api/verify/captcha',headers=self.__headers).content

    def login(self,captcha):
        LoginRequest = {
            'username': self.__username,
            'password': self.__password,
            'captcha': captcha
        }
        LoginResponse = self.__session.post('https://www.luogu.com.cn/api/auth/userPassLogin',headers=self.__headers,json=LoginRequest).json()
        self.__username = LoginResponse['username']
        self.__syncToken = LoginResponse['syncToken']
        self.__session.get('https://www.luogu.com.cn'+LoginResponse['redirectTo'],headers=self.__headers)

    @Deprecated
    def sync(self):
        r = self.__session.post('https://www.luogu.org/api/auth/syncLogin',headers=self.__headers,json={'syncToken':self.__syncToken}).json()
        print(r)
        self.__uid = r['uid']

    @Deprecated
    def getUid(self):
        return self.__uid

    def getUsername(self):
        return self.__username

    def getProblems(self,searchJson):
        parms = urllib.parse.urlencode(searchJson)
        return self.__session.get('https://www.luogu.com.cn/problem/list?'+parms,headers=self.__headers).json()

    def getSession(self):
        return self.__session


import setuptools

with open('README.md', 'r') as fh:
  long_description = fh.read()

setuptools.setup(
  name='luogulib',
  version='1.1.0',
  author='Qin Yuzhen',
  author_email='15166054530@163.com',
  description='A python module for using Luogu API.',
  long_description=long_description,
  long_description_content_type='text/markdown',
  url='https://gitee.com/cyoi-group/luogu-lib',
  packages=setuptools.find_packages(),
  classifiers=[
      'Development Status :: 3 - Alpha',
      'Intended Audience :: Developers',
      'Intended Audience :: Information Technology',
      'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
      'Natural Language :: Chinese (Simplified)',
      'Operating System :: MacOS',
      'Operating System :: Microsoft :: Windows',
      'Operating System :: POSIX :: Linux',
      'Programming Language :: Python :: 3',
      'Topic :: Software Development :: Libraries :: Python Modules'
  ],
  install_requires=[
        'bs4',
        'requests',
        'PIL'
    ]
)